# Changelog

<!-- prettier-ignore -->
Name | PR | Developer | Date | Version
--- | --- | --- | --- | ---
:building_construction: Do not use reflect | [1](https://github.com/laminlabs/lndb-rest/pull/1) | [falexwolf](https://github.com/falexwolf) | 2023-03-12 |
